@@ -1,6 +1,6 @@
-package T16;
+package T17;
 use Object::Simple;
 
-sub m1 : Attr { auto_build => 1}
+sub m1 : Attr {default => {}}
 
 Object::Simple->end;
